//
//  YHHKRecordsEditContentVC.swift
//  galaxy
//
//  Created by alexzzw on 2024/9/18.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import JXSegmentedView
import IQKeyboardManagerSwift

class YHHKRecordsEditContentVC: YHBaseViewController {
    
    enum YHHKRecordsEditPageType {
        case add, edit
        
        var title: String {
            switch self {
            case .add:
                return "新增在港记录"
            case .edit:
                return "编辑在港记录"
            }
        }
    }
    
    enum RowType {
        case tips(_ title: String, _ detail: NSAttributedString)
        case header(_ title: String)
        case personnelStaying(_ title: String, _ detail: [YHHKRecordsEditPersonnelModel])
        case selectTime(_ title: String, _ detail: String?, _ placeholder: String)
        case remark(_ title: String, _ detail: String)
    }
    
    private var datas: [[RowType]] = []
    
    private lazy var tableView: UITableView = {
        let view = UITableView(frame:.zero, style:.grouped)
        view.estimatedSectionHeaderHeight = 16.0
        view.estimatedSectionFooterHeight = 0.01
        view.sectionHeaderHeight = 16.0
        view.sectionFooterHeight = 0.01
        view.contentInsetAdjustmentBehavior = .never
        view.showsVerticalScrollIndicator = false
        view.separatorStyle = .none
        view.delegate = self
        view.dataSource = self
        view.backgroundColor = .clear
        view.tableFooterView = UITableViewHeaderFooterView()
        view.register(YHResignDocumentTipsCell.self, forCellReuseIdentifier: YHResignDocumentTipsCell.cellReuseIdentifier)
        view.register(YHHKRecordsTitleCell.self, forCellReuseIdentifier: YHHKRecordsTitleCell.cellReuseIdentifier)
        view.register(YHHKRecordsRemarkCell.self, forCellReuseIdentifier: YHHKRecordsRemarkCell.cellReuseIdentifier)
        view.register(YHHKRecordsTimeSelectCell.self, forCellReuseIdentifier: YHHKRecordsTimeSelectCell.cellReuseIdentifier)
        view.register(YHHKRecordsStayingPersonnelCell.self, forCellReuseIdentifier: YHHKRecordsStayingPersonnelCell.cellReuseIdentifier)
        view.keyboardDismissMode = .onDrag
        return view
    }()
    
    private lazy var bottomView: UIView = {
        let view = UIView()
        view.backgroundColor = .white
        return view
    }()
    
    private lazy var saveButton: UIButton = {
        let button = UIButton(type: .custom)
        button.titleLabel?.font = UIFont.PFSC_M(ofSize: 16)
        let buttonName = "保存逗留记录"
        button.setTitle(buttonName, for: .normal)
        button.setTitle(buttonName, for: .highlighted)
        button.setTitleColor( UIColor(hex:0xffffff), for: .normal)
        button.setTitleColor( UIColor(hex:0xffffff), for: .highlighted)
        button.addTarget(self, action: #selector(clickSaveButton), for: .touchUpInside)
        button.layer.cornerRadius = kCornerRadius3
        button.clipsToBounds = true
        button.backgroundColor = .brandMainColor
        return button
    }()
    
    private var personnelStayingHeight: CGFloat?
    
    private let pageType: YHHKRecordsEditPageType
    init(pageType: YHHKRecordsEditPageType) {
        self.pageType = pageType
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        IQKeyboardManager.shared.enable = true
        setupData()
    }

    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        IQKeyboardManager.shared.enable = false
    }
}

extension YHHKRecordsEditContentVC {
    private func setupUI() {
        gk_navBarAlpha = 1
        gk_navTitle = pageType.title
        
        view.backgroundColor = UIColor.contentBkgColor
        view.addSubview(tableView)
        view.addSubview(bottomView)
        bottomView.addSubview(saveButton)
        
        bottomView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.right.equalToSuperview()
            make.bottom.equalTo(view.safeAreaLayoutGuide.snp.bottom)
            make.height.equalTo(64)
        }
        
        saveButton.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(kMargin)
            make.right.equalToSuperview().offset(-kMargin)
            make.centerY.equalToSuperview()
            make.height.equalTo(48)
        }
        
        tableView.snp.makeConstraints { make in
            make.left.equalToSuperview()
            make.right.equalToSuperview()
            make.top.equalTo(k_Height_NavigationtBarAndStatuBar)
            make.bottom.equalTo(bottomView.snp.top)
        }
        tableView.tableFooterView = UIView(frame: CGRect.init(x: 0, y: 0, width: KScreenWidth, height: kMargin))
    }
    
    private func setupData() {
        let names: [String] = ["钻石王老五·钻石王老五·名字很长·长到放不哈哈哈哈哈哈", "玛尔扎哈", "李白", "王晓霞", "巴斯"]
        let personnels = names.map { name in
            YHHKRecordsEditPersonnelModel(name: name)
        }

        datas = [[.tips("温馨提示：", getTips())], [.header("在港逗留记录"), .personnelStaying("逗留人员", personnels), .selectTime("入境时间", nil, "请选择"), .selectTime("离境时间", "2018-07-31", "请选择"), .remark("备注", "这里是备注信息这里是备注信息这里是备注信息这里是备注信息这里是备注信息这里是备注信息这里是备注信息这里是备注信息这里是备注信息")]]
        tableView.reloadData()
    }
    
    @objc private func clickSaveButton() {
        //
    }
}

extension YHHKRecordsEditContentVC: JXSegmentedListContainerViewListDelegate {
    func listView() -> UIView {
        return view
    }
}

extension YHHKRecordsEditContentVC: UITableViewDelegate, UITableViewDataSource {
    func numberOfSections(in tableView: UITableView) -> Int {
        return datas.count
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        guard datas.count > section else {
            return 0
        }
        let sectionArr = datas[section]
        return sectionArr.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        guard datas.count > indexPath.section else {
            return UITableViewCell()
        }
        let sectionArr = datas[indexPath.section]
        guard sectionArr.count > indexPath.row else {
            return UITableViewCell()
        }
        let row = sectionArr[indexPath.row]
        switch row {
        case let .remark(title, detail):
            if let cell = tableView.dequeueReusableCell(withIdentifier: YHHKRecordsRemarkCell.cellReuseIdentifier) as? YHHKRecordsRemarkCell {
                cell.setupCellInfo(title: title, titleColor: .mainTextColor, detail: detail, isEditable: true, cellType: .bottom)
                return cell
            }
        case let .tips(title, detail):
            if let cell = tableView.dequeueReusableCell(withIdentifier: YHResignDocumentTipsCell.cellReuseIdentifier) as? YHResignDocumentTipsCell {
                cell.setupCellInfo(title: title, detail: detail, detailColor: .mainTextColor70)
                return cell
            }
        case let .header(title):
            if let cell = tableView.dequeueReusableCell(withIdentifier: YHHKRecordsTitleCell.cellReuseIdentifier) as? YHHKRecordsTitleCell {
                cell.setupCellInfo(title)
                return cell
            }
        case let .personnelStaying(title, personnels):
            if let cell = tableView.dequeueReusableCell(withIdentifier: YHHKRecordsStayingPersonnelCell.cellReuseIdentifier) as? YHHKRecordsStayingPersonnelCell {
                cell.setupCellInfo(title: title)
                cell.collectionData = personnels
                cell.didHeightChanged = { [weak self] height in
                    self?.personnelStayingHeight = height
                    self?.tableView.performBatchUpdates { [weak tableView] in
                        guard let tableView = tableView else {
                            return
                        }
                        tableView.reloadRows(at: [indexPath], with: .none)
                    }
                }
                return cell
            }
        case let .selectTime(title, detail, placeholder):
            if let cell = tableView.dequeueReusableCell(withIdentifier: YHHKRecordsTimeSelectCell.cellReuseIdentifier) as? YHHKRecordsTimeSelectCell {
                cell.setupCellInfo(title: title, detail: detail, placeholder: placeholder)
                return cell
            }
        }
        return UITableViewCell()
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        guard datas.count > indexPath.section else {
            return
        }
        let sectionArr = datas[indexPath.section]
        guard sectionArr.count > indexPath.row else {
            return
        }
        let row = sectionArr[indexPath.row]
        
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        guard datas.count > indexPath.section else {
            return 0
        }
        let sectionArr = datas[indexPath.section]
        guard sectionArr.count > indexPath.row else {
            return 0
        }
        let row = sectionArr[indexPath.row]
        switch row {
        
        case .remark:
            return 146
        case .tips:
            return UITableView.automaticDimension
        case .header:
            return 52
        case .personnelStaying:
            if let personnelStayingHeight = personnelStayingHeight {
                return personnelStayingHeight
            }
            return UITableView.automaticDimension
        case .selectTime:
            return 52
        }
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        return UIView()
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return UIView()
    }
}

extension YHHKRecordsEditContentVC {
    
    private func getTips() -> NSAttributedString {
        let normalTextFirst = "您好，所有家庭成员赴港时间"
        let attText = "间隔不能超出180天"
        let normalTextLast = "（红线）如超出，递交续签时需向港府解释说明连续180未赴港原因。主申请人赴港频率越高，逗留时间越长，续签成功率越高哦~"
        let attStr = NSMutableAttributedString(string: normalTextFirst + attText + normalTextLast)
        attStr.setAttributes([.foregroundColor: UIColor.brandMainColor], range: NSRange(location: normalTextFirst.count, length: attText.count))
        return attStr
    }
}
